load_data: Load data

Description Usage Arguments Value Examples

View source: R/processed_data.R

Description

Loads multiple files of data and extracts features that are desired. It also formats the date and puts data in date order.

Usage

1
load_data(file_list, variables = FALSE)

Arguments

file_list

a list of files to be loaded.

variables

the variables from the files that we wish to load.

Value

A data frame with columns for each variable and each row is a match.

Examples

1
2
load_data("wta_matches_2000.csv")
load_data(file_list, variables = c('tourney_date','surface', 'winner_id', 'loser_id', 'winner_age', 'loser_age'))

ss15859/tennis.wta documentation built on Jan. 24, 2021, 12:46 a.m.