Description Usage Arguments Value Examples
View source: R/processed_data.R
Loads multiple files of data and extracts features that are desired. It also formats the date and puts data in date order.
1 |
file_list |
a list of files to be loaded. |
variables |
the variables from the files that we wish to load. |
A data frame with columns for each variable and each row is a match.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.